;; skk-cursor2.el -- Specify current input mode in skk9.6 with color cursor.

;;; Copyright (C) Hiroshi YOKOTA.

;; Author: Hiroshi YOKOTA:y5t0964@students.chiba-u.ac.jp
;; Maintainer: Hiroshi YOKOTA <y5t0964@students.chiba-u.ac.jp>
;; Version: 1.1
;; Keywords: skk color color-mate kanakan-cursor
;; Content-Type: text/plain; charset=x-euc-jp

;;; This file is part of kanakan-cursor.

;; History:
;; skk-cursor.el for Color-Mate Ver.1.0:
;;    o Initial version.
;; skk-cursor.el for Color-Mate Ver.1.1:
;;    o xemacs "japanese-skk" suport.


;;; Usage: 
;; Install:
;; 1. Setup skk version 9.6 or later.
;; 2. Write "(require 'skk-cursor2)" to your ~/.emacs
;; 3. Restart emacs/mule/xemacs

;; $Id: skk-cursor2.el,v 1.4 1998/09/22 10:16:40 elca Exp $

;; for skk version 9.6
;; skk version 9.6 の場合は、 skk 側で用意されたカーソル色変更機構を
;; 利用する。

(setq skk-use-color-cursor t)

(setq skk-ascii-cursor-color "ivory4")
(setq skk-default-cursor-color "navy")
(setq skk-kana-cursor-color "forestgreen")
(setq skk-katakana-cursor-color "coral4")
(setq skk-zenkaku-cursor-color "gold")

;; xemacs
(setq skk-hirakana-cursor-color "forestgreen")


(provide 'skk-cursor2)

;; skk-cursor2.el ends here
