;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; This file only use when compiling. ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; このファイルはコンパイル時のみ必要となる。

;$Id: color-mate-compile.el,v 9.10 1998/10/06 15:31:46 elca Exp $

;; set path where "*.el" exists.
(setq load-path (cons "." load-path))

; This macro comes from hilit19.el
;; hilit19.el,v 2.19 1993/09/08 18:44:10 stig Release
(defmacro hilit-translate (&rest args)
  "(hilit-translate FROM TO FROM TO ...): translate each face FROM to the
value of its TO face.  This is like setq for faces.

The function hilit-lookup-face-create will repeatedly translate until no more
translations for the face exist in the translation table.

See the documentation for hilit-lookup-face-create for names of valid faces."
  (or (zerop (% (length args) 2))
      (error "wrong number of args"))
  (let (cmdl from to)
    (while args
      (setq from (car args) to (nth 1 args) args (nthcdr 2 args)
	    cmdl (cons (list 'hilit-associate ''hilit-face-translation-table
			     (list 'quote from) to)
		       cmdl)))
    (cons 'progn cmdl)))

; This function comes from hilit19.el
(defun hilit-associate (alist key val)
  "It's dummy function."
  nil)

; These values comes from egg.el
(defvar egg:*fence-face*         nil "It's dummy variable.")
(defvar egg:*henkan-face*        nil "It's dummy variable.")
(defvar egg:*fence-face-in-cont* nil "It's dummy variable.")
(defvar egg:*dai-bunsetu-face*   nil "It's dummy variable.")
(defvar egg:*sho-bunsetu-face*   nil "It's dummy variable.")

;; It's comes from canna.el.
(defvar canna-empty-info nil "It's dummy variable.")
(defvar canna-use-color nil "It's dummy variable.")

; This function comes from can-n-egg.el
(defun can-n-egg ()
  "It's dummy function."
  nil)

; This function comes from canna.el
(defun canna ()
  "It's dummy function."
  nil)

; It's comes from paren.el (xemacs)
(defvar paren-mode nil "It's dummy variable.")

; It's comes from faces.el (xemacs)
(defun face-background-name (FACE &optional DOMAIN DEFAULT NO-FALLBACK)
  "It's dummy function."
  nil)
(defun face-foreground-name (FACE &optional DOMAIN DEFAULT NO-FALLBACK)
  "It's dummy function."
  nil)

; It's comes from skk.el
(defvar skk-use-face nil "It's dummy variable.")
; It's comes from skk-e19.el
(defvar skk-henkan-face nil "It's dummy variable.")

; emacs20 international/fontset.el
(defun create-fontset-from-fontset-spec (FONTSET-SPEC &optional STYLE NOERROR)
  "It's dummy function."
  nil)
; emacs20 international/kkc.el
(defvar kkc-overlay-head nil "It's dummy variable.")
; emacs20 international/quail.el
(defvar quail-conv-overlay nil "It's dummy variable.")

; emacs20 custom.el
(defun custom-set-variables (&rest ARGS)
  "It's dummy function."
  nil)

; mule built in
(defun fontsetp (fontset)
  "It's dummy function."
  nil)
(defun delete-overlay (OVERLAY)
  "It's dummy function."
  nil)
(defun make-overlay (BEG END &optional BUFFER FRONT-ADVANCE REAR-ADVANCE)
  "It's dummy function."
  nil)
(defun overlay-put (OVERLAY PROP VALUE)
  "It's dummy function."
  nil)
(defun new-fontset (NAME FONTNAMES)
  "It's dummy function."
  nil)

; mule term/x-win
(defun fontset-string-to-vector (STR FONTS)
  "It's dummy function."
  nil)

; mule compiled Lisp function
(defun set-background-color (COLOR-NAME)
  "It's dummy function."
  nil)
(defun set-foreground-color (COLOR-NAME)
  "It's dummy function."
  nil)
(defun set-mouse-color (COLOR-NAME)
  "It's dummy function."
  nil)

; xemacs interactive Lisp function
(defun paren-set-mode (ARG &optional QUIET)
  "It's dummy function."
  nil)
; xemacs builtin
(defun make-color-instance (NAME &optional DEVICE NO-ERROR)
  "It's dummy function."
  nil)
; xemacs frame.el
(defun set-frame-property (FRAME PROP VAL)
  "It's dummy function."
  nil)
; xemacs builtin
(defun color-instance-p (OBJECT)
  "It's dummy function."
  nil)

; emacs/mule
(defvar default-frame-alist nil "It's dummy variable.")
(defvar initial-frame-alist nil "It's dummy variable.")
; xemacs
(defvar default-frame-plist nil "It's dummy variable.")
(defvar initial-frame-plist nil "It's dummy variable.")

;; color-mate-compile.el ends here.
