;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; This file only use when compiling. ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; このファイルはコンパイル時のみ必要となる。

;$Id: color-mate-theme-compile.el,v 1.3 1998/10/06 04:16:11 elca Exp $

(require 'assoc)

;; set path where "*.el" exists.
(setq load-path (cons ".." load-path))

(defvar color-mate:theme nil)
