;; color-mate-e20-fontset.el Emacs 20.x fontset definition file for Emacs 20.x

;; Copyright (C) YOKOTA Hiroshi

;; Author: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>
;; Maintainer: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>
;; Version: 10.0
;; Keywords: color color-mate
;; Content-Type: text/plain; charset=x-euc-jp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Color-Mate  Ver.10.0
;;         by 横田 裕思 (yokota@netlab.is.tsukuba.ac.jp)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Coloring mule/emacs to more easier and more fun.
;;   mule / emacs で、色を使用して見やすい画面にします。
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; This file is part of Color-Mate

;; $Id: color-mate-e20-fontset.el,v 10.2 1999/08/05 23:11:25 elca Exp $

(require 'assoc)

;; 12 dot
(create-fontset-from-fontset-spec
 "-*-fixed-medium-r-normal-*-12-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-r-normal-*-12-*-*-*-*-*-fontset-standard"
      "fontset-12")

(create-fontset-from-fontset-spec
 "-*-fixed-bold-r-normal-*-12-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-bold-r-normal-*-12-*-*-*-*-*-fontset-standard"
      "fontset-12-bold")

(create-fontset-from-fontset-spec
 "-*-fixed-medium-i-normal-*-12-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-i-normal-*-12-*-*-*-*-*-fontset-standard"
      "fontset-12-italic")


;; 14 dot
(create-fontset-from-fontset-spec
 "-*-fixed-medium-r-normal-*-14-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-r-normal-*-14-*-*-*-*-*-fontset-standard"
      "fontset-14")

(create-fontset-from-fontset-spec
 "-*-fixed-bold-r-normal-*-14-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-bold-r-normal-*-14-*-*-*-*-*-fontset-standard"
      "fontset-14-bold")

(create-fontset-from-fontset-spec
 "-*-fixed-medium-i-normal-*-14-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-i-normal-*-14-*-*-*-*-*-fontset-standard"
      "fontset-14-italic")


;; 16 dot
(create-fontset-from-fontset-spec
 "-*-fixed-medium-r-normal-*-16-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-r-normal-*-16-*-*-*-*-*-fontset-standard"
      "fontset-16")
(aput 'fontset-alias-alist
      "-*-fixed-medium-r-normal-*-16-*-*-*-*-*-fontset-standard"
      "fontset-standard")

(create-fontset-from-fontset-spec
 "-*-fixed-bold-r-normal-*-16-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-bold-r-normal-*-16-*-*-*-*-*-fontset-standard"
      "fontset-16-bold")

(create-fontset-from-fontset-spec
 "-*-fixed-medium-i-normal-*-16-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-i-normal-*-16-*-*-*-*-*-fontset-standard"
      "fontset-16-italic")


;; 24 dot
(create-fontset-from-fontset-spec
 "-*-fixed-medium-r-normal-*-24-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-r-normal-*-24-*-*-*-*-*-fontset-standard"
      "fontset-24")

(create-fontset-from-fontset-spec
 "-*-fixed-bold-r-normal-*-24-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-bold-r-normal-*-24-*-*-*-*-*-fontset-standard"
      "fontset-24-bold")

(create-fontset-from-fontset-spec
 "-*-fixed-medium-i-normal-*-24-*-*-*-*-*-fontset-standard"
 nil 'noerror)
(aput 'fontset-alias-alist
      "-*-fixed-medium-i-normal-*-24-*-*-*-*-*-fontset-standard"
      "fontset-24-italic")


;; color-mate-e20-fontset.el ends here
