! CM_FILENAME : -*- xrdb -*-
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!
!!   Color-Mate  Ver.10.0
!!         by 横田 裕思 (yokota@netlab.is.tsukuba.ac.jp)
!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!
!!   Coloring mule/emacs/xemacs to more easier and more fun.
!!   mule / emacs / xemacs で、色を使用して見やすい画面にします
!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

!! Author: Hiroshi Yokota <yokota@netlab.is.tsukuba.ac.jp>
!! Maintainer: Hiroshi Yokota <yokota@netlab.is.tsukuba.ac.jp>
!! Version: 10.0
!! Keywords: color hilit19 font-lock color-mate
!! Content-Type: text/plain; charset=x-euc-jp

!$Id: Xdefaults.cpp,v 10.1 1999/08/05 23:47:38 elca Exp $

!ダイアログボックス
!dialog box
! ウィンドウの背景と文字の色
! background/foreground
	Emacs*dialog*background: CM_BG
	Emacs*dialog*foreground: CM_FG

! ボタンの色とボタンの文字の色とボタンの形
! buttons
	Emacs*dialog*button1.foreground: CM_BUTTON_FG
	Emacs*dialog*button1.background: CM_BUTTON_BG
	Emacs*dialog*button1.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button2.foreground: CM_BUTTON_FG
	Emacs*dialog*button2.background: CM_BUTTON_BG
	Emacs*dialog*button2.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button3.foreground: CM_BUTTON_FG
	Emacs*dialog*button3.background: CM_BUTTON_BG
	Emacs*dialog*button3.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button4.foreground: CM_BUTTON_FG
	Emacs*dialog*button4.background: CM_BUTTON_BG
	Emacs*dialog*button4.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button5.foreground: CM_BUTTON_FG
	Emacs*dialog*button5.background: CM_BUTTON_BG
	Emacs*dialog*button5.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button6.foreground: CM_BUTTON_FG
	Emacs*dialog*button6.background: CM_BUTTON_BG
	Emacs*dialog*button6.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button7.foreground: CM_BUTTON_FG
	Emacs*dialog*button7.background: CM_BUTTON_BG
	Emacs*dialog*button7.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button8.foreground: CM_BUTTON_FG
	Emacs*dialog*button8.background: CM_BUTTON_BG
	Emacs*dialog*button8.shapeStyle: CM_BUTTON_SHAPE
	Emacs*dialog*button9.foreground: CM_BUTTON_FG
	Emacs*dialog*button9.background: CM_BUTTON_BG
	Emacs*dialog*button9.shapeStyle: CM_BUTTON_SHAPE


!メニューバー
!menu bar
! メニューバーの背景と文字の色
	Emacs*menubar.background: CM_BUTTON_BG
	Emacs*menubar.foreground: CM_BUTTON_FG


!ポップアップメニュー
!popup menu
! ポップアップメニューの背景と文字の色
	Emacs*popup.background: CM_BUTTON_BG
	Emacs*popup.foreground: CM_BUTTON_FG


!!
!! for XEmacs only
!!
! "check box" or "radio button" color
	xemacs*menubar.selectColor: CM_CHECK
	xemacs*popup.selectColor: CM_CHECK
! menu/popup highlight color
	xemacs*menubar.highlightForeground: CM_HIGHLIGHT_FG
	xemacs*popup.highlightForeground: CM_HIGHLIGHT_FG
! popup title color
	xemacs*popup.titleForeground: CM_BUTTON_FG

!!! color-mate.Xdefaults.add ends here
