;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; This file only use when compiling. ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; このファイルはコンパイル時のみ必要となる。

(defvar color-mate:theme-file nil)

; mule builtin
(defun delete-overlay (OVERLAY)
  "It's dummy function."
  nil)
(defun make-overlay (BEG END &optional BUFFER FRONT-ADVANCE REAR-ADVANCE)
  "It's dummy function."
  nil)
(defun overlay-put (OVERLAY PROP VALUE)
  "It's dummy function."
  nil)

; contrib-compile.el ends here.
