;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; This file only use when compiling. ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; このファイルはコンパイル時のみ必要となる。

;$Id: kanakan-cursor-compile.el,v 1.5 1999/08/05 23:34:42 elca Exp $

;; set path where "*.el" exists.
(setq load-path (cons "." load-path))
(setq load-path (cons ".." load-path))


;; It's comes from frame.el.
;; at function (make-frame).
(defvar nframe nil "It's dummy variable.")

;; It's comes from skk-e19.el
(defvar skk-use-color-cursor nil "It's dummy variable.")

;; comes from faces.el
(defun face-background-name (FACE &optional DOMAIN DEFAULT NO-FALLBACK)
  nil)

;;
(defvar henkan-mode-map nil)
(defvar select-window-hook nil)
(defvar minibuffer-window-selected nil)
(defvar minibuffer-preprompt nil)

;; skk
(defvar skk-ascii-cursor-color nil "It's dummy variable.")
(defvar skk-default-cursor-color nil "It's dummy variable.")
(defvar skk-kana-cursor-color nil "It's dummy variable.")
(defvar skk-katakana-cursor-color nil "It's dummy variable.")
(defvar skk-zenkaku-cursor-color nil "It's dummy variable.")
(defvar skk-hirakana-cursor-color nil "It's dummy variable.")

;; end
